@@ -20,6 +20,9 @@ pub enum ContractError {
 
     #[error("Drand round already added {0}")]
     DrandRoundAlreadyAdded(String),
+
+    #[error("Error parsing reply")]
+    ParseReplyError {},
     // Add any other custom errors you like here.
     // Look at https://docs.rs/thiserror/1.0.21/thiserror/ for details.
 }
